@@ -1,6 +1,6 @@
 /*
  * sar, sadc, sadf, mpstat and iostat common routines.
- * (C) 1999-2009 by Sebastien GODARD (sysstat <at> orange.fr)
+ * (C) 1999-2011 by Sebastien GODARD (sysstat <at> orange.fr)
  *
  ***************************************************************************
  * This program is free software; you can redistribute it and/or modify it *
@@ -54,9 +54,9 @@ unsigned int kb_shift;
  */
 void print_version(void)
 {
-	fprintf(stderr, _("sysstat version %s\n"), VERSION);
-	fprintf(stderr, "(C) Sebastien Godard (sysstat <at> orange.fr)\n");
-	exit(1);
+	printf(_("sysstat version %s\n"), VERSION);
+	printf("(C) Sebastien Godard (sysstat <at> orange.fr)\n");
+	exit(0);
 }
 
 /*
@@ -264,39 +264,34 @@ int get_sysfs_dev_nr(int display_partitions)
 
 /*
  ***************************************************************************
- * Find number of NFS-mounted points that are registered in
- * /proc/self/mountstats.
+ * Read /proc/devices file and get device-mapper major number.
+ * If device-mapper entry is not found in file, use DEFAULT_DEMAP_MAJOR
+ * number.
  *
  * RETURNS:
- * Number of NFS-mounted points.
+ * Device-mapper major number.
  ***************************************************************************
  */
-int get_nfs_mount_nr(void)
+unsigned int get_devmap_major(void)
 {
 	FILE *fp;
-	char line[8192];
-	char type_name[10];
-	unsigned int nfs = 0;
+	char line[128];
+	unsigned int dm_major = DEFAULT_DEVMAP_MAJOR;
 
-	if ((fp = fopen(NFSMOUNTSTATS, "r")) == NULL)
-		/* File non-existent */
-		return 0;
+	if ((fp = fopen(DEVICES, "r")) == NULL)
+		return dm_major;
 
-	while (fgets(line, 8192, fp) != NULL) {
+	while (fgets(line, 128, fp) != NULL) {
 
-		if ((strstr(line, "mounted")) && (strstr(line, "on")) &&
-		    (strstr(line, "with")) && (strstr(line, "fstype"))) {
-	
-			sscanf(strstr(line, "fstype") + 6, "%10s", type_name);
-			if ((!strncmp(type_name, "nfs", 3)) && (strncmp(type_name, "nfsd", 4))) {
-				nfs ++;
-			}
+		if (strstr(line, "device-mapper")) {
+			/* Read device-mapper major number */
+			sscanf(line, "%u", &dm_major);
 		}
 	}
 
 	fclose(fp);
 
-	return nfs;
+	return dm_major;
 }
 
 /*
@@ -322,7 +317,10 @@ int print_gal_header(struct tm *rectime, char *sysname, char *release,
 	char *e;
 	int rc = 0;
 
-	if (((e = getenv(ENV_TIME_FMT)) != NULL) && !strcmp(e, K_ISO)) {
+	if (rectime == NULL) {
+		strcpy(cur_date, "?/?/?");
+	}
+	else if (((e = getenv(ENV_TIME_FMT)) != NULL) && !strcmp(e, K_ISO)) {
 		strftime(cur_date, sizeof(cur_date), "%Y-%m-%d", rectime);
 		rc = 1;
 	}
@@ -566,12 +564,14 @@ unsigned long long get_per_cpu_interval(struct stats_cpu *scc,
  * @error_code	Error code.
  ***************************************************************************
  */
+#ifdef DEBUG
 void sysstat_panic(const char *function, int error_code)
 {
 	fprintf(stderr, "sysstat: %s[%d]: Last chance handler...\n",
 		function, error_code);
 	exit(1);
 }
+#endif
 
 /*
  ***************************************************************************
